@@ -20,7 +20,7 @@ DXAnalysis Handler
 
 Analyses are DNAnexus entities that capture an instantiation of a
 running workflow. They can be created from
-:func:`dxpy.bindings.dxworkflow.DXAnalysisWorkflow.run` or from an
+:func:`dxpy.bindings.dxworkflow.DXWorkflow.run` or from an
 existing analysis ID.
 
 """
@@ -121,7 +121,7 @@ class DXAnalysis(DXObject):
 
         dxpy.api.analysis_set_properties(self._dxid, {"properties": properties}, **kwargs)
 
-    def wait_on_done(self, interval=2, timeout=sys.maxint, **kwargs):
+    def wait_on_done(self, interval=2, timeout=3600*24*7, **kwargs):
         '''
         :param interval: Number of seconds between queries to the analysis's state
         :type interval: integer
